@@ -1,5 +1,5 @@
 package Data::TableReader::Decoder::XLSX;
-$Data::TableReader::Decoder::XLSX::VERSION = '0.003';
+$Data::TableReader::Decoder::XLSX::VERSION = '0.004';
 use Moo 2;
 use Carp;
 use Try::Tiny;
@@ -10,11 +10,11 @@ our $default_xlsx_module;
 sub default_xlsx_module {
 	$default_xlsx_module ||= do {
 		eval "require $_" && return $_ for @xlsx_probe_modules;
-		croak "No CSV parser available; install one of: ".join(', ', @xlsx_probe_modules);
+		croak "No XLSX parser available; install one of: ".join(', ', @xlsx_probe_modules);
 	};
 }
 
-# ABSTRACT: Access sheets/rows of a modern XML-based Microsoft Excel spreadsheet
+# ABSTRACT: Access sheets/rows of a modern Microsoft Excel workbook
 
 
 sub _build_workbook {
@@ -47,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Data::TableReader::Decoder::XLSX - Access sheets/rows of a modern XML-based Microsoft Excel spreadsheet
+Data::TableReader::Decoder::XLSX - Access sheets/rows of a modern Microsoft Excel workbook
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
